<?php

namespace SearchWP\Dependencies;

// code source:  https://github.com/devgeniem/wp-sanitize-accented-uploads/blob/master/plugin.php#L152
// table source: http://www.i18nqa.com/debug/utf8-debug.html
return [
    // 3 char errors
    'â€š' => '‚',
    'â€ž' => '„',
    'â€¦' => '…',
    'â€¡' => '‡',
    'â€°' => '‰',
    'â€¹' => '‹',
    'â€˜' => '‘',
    'â€™' => '’',
    'â€œ' => '“',
    'â€¢' => '•',
    'â€“' => '–',
    'â€”' => '—',
    'â„¢' => '™',
    'â€º' => '›',
    'â‚¬' => '€',
    // 2 char errors
    "" => "€",
    // EURO SIGN
    "" => "‚",
    // SINGLE LOW-9 QUOTATION MARK
    "" => "ƒ",
    // LATIN SMALL LETTER F WITH HOOK
    "" => "„",
    // DOUBLE LOW-9 QUOTATION MARK
    "" => "…",
    // HORIZONTAL ELLIPSIS
    "" => "†",
    // DAGGER
    "" => "‡",
    // DOUBLE DAGGER
    "" => "ˆ",
    // MODIFIER LETTER CIRCUMFLEX ACCENT
    "" => "‰",
    // PER MILLE SIGN
    "" => "Š",
    // LATIN CAPITAL LETTER S WITH CARON
    "" => "‹",
    // SINGLE LEFT-POINTING ANGLE QUOTE
    "" => "Œ",
    // LATIN CAPITAL LIGATURE OE
    "" => "Ž",
    // LATIN CAPITAL LETTER Z WITH CARON
    "" => "‘",
    // LEFT SINGLE QUOTATION MARK
    "" => "’",
    // RIGHT SINGLE QUOTATION MARK
    "" => "“",
    // LEFT DOUBLE QUOTATION MARK
    "" => "”",
    // RIGHT DOUBLE QUOTATION MARK
    "" => "•",
    // BULLET
    "" => "–",
    // EN DASH
    "" => "—",
    // EM DASH
    "" => "˜",
    // SMALL TILDE
    'Ã‚' => 'Â',
    'Æ’' => 'ƒ',
    'Ãƒ' => 'Ã',
    'Ã„' => 'Ä',
    'Ã…' => 'Å',
    //'â€'       => '†', // duplicate key
    'Ã†' => 'Æ',
    'Ã‡' => 'Ç',
    'Ë†' => 'ˆ',
    'Ãˆ' => 'È',
    'Ã‰' => 'É',
    'ÃŠ' => 'Ê',
    'Ã‹' => 'Ë',
    'Å’' => 'Œ',
    'ÃŒ' => 'Ì',
    'Å½' => 'Ž',
    'ÃŽ' => 'Î',
    'Ã‘' => 'Ñ',
    'Ã’' => 'Ò',
    'Ã“' => 'Ó',
    'â€' => '”',
    'Ã”' => 'Ô',
    'Ã•' => 'Õ',
    'Ã–' => 'Ö',
    'Ã—' => '×',
    'Ëœ' => '˜',
    'Ã˜' => 'Ø',
    'Ã™' => 'Ù',
    'Å¡' => 'š',
    'Ãš' => 'Ú',
    'Ã›' => 'Û',
    'Å“' => 'œ',
    'Ãœ' => 'Ü',
    'Å¾' => 'ž',
    'Ãž' => 'Þ',
    'Å¸' => 'Ÿ',
    'ÃŸ' => 'ß',
    'Â¡' => '¡',
    'Ã¡' => 'á',
    'Â¢' => '¢',
    'Ã¢' => 'â',
    'Â£' => '£',
    'Ã£' => 'ã',
    'Â¤' => '¤',
    'Ã¤' => 'ä',
    'Â¥' => '¥',
    'Ã¥' => 'å',
    'Â¦' => '¦',
    'Ã¦' => 'æ',
    'Â§' => '§',
    'Ã§' => 'ç',
    'Â¨' => '¨',
    'Ã¨' => 'è',
    'Â©' => '©',
    'Ã©' => 'é',
    'Âª' => 'ª',
    'Ãª' => 'ê',
    'Â«' => '«',
    'Ã«' => 'ë',
    'Â¬' => '¬',
    'Ã¬' => 'ì',
    'Â®' => '®',
    'Ã®' => 'î',
    'Â¯' => '¯',
    'Ã¯' => 'ï',
    'Â°' => '°',
    'Ã°' => 'ð',
    'Â±' => '±',
    'Ã±' => 'ñ',
    'Â²' => '²',
    'Ã²' => 'ò',
    'Â³' => '³',
    'Ã³' => 'ó',
    'Â´' => '´',
    'Ã´' => 'ô',
    'Âµ' => 'µ',
    'Ãµ' => 'õ',
    'Â¶' => '¶',
    'Ã¶' => 'ö',
    'Â·' => '·',
    'Ã·' => '÷',
    'Â¸' => '¸',
    'Ã¸' => 'ø',
    'Â¹' => '¹',
    'Ã¹' => 'ù',
    'Âº' => 'º',
    'Ãº' => 'ú',
    'Â»' => '»',
    'Ã»' => 'û',
    'Â¼' => '¼',
    'Ã¼' => 'ü',
    'Â½' => '½',
    'Ã½' => 'ý',
    'Â¾' => '¾',
    'Ã¾' => 'þ',
    'Â¿' => '¿',
    'Ã¿' => 'ÿ',
    'Ã€' => 'À',
];
